summaryrefslogtreecommitdiffhomepage
path: root/lib
diff options
context:
space:
mode:
authorJurriaan Pruis <[email protected]>2012-03-02 10:23:03 +0100
committerJurriaan Pruis <[email protected]>2012-03-02 10:23:03 +0100
commitca7248353d295c74f3dff7e8e003044849c026e7 (patch)
treecd4e3c831f5037c62f2e33d0134a223ad5c1f423 /lib
parent99e0fd6d70b48df1e09b6f234b2512893eae9ff6 (diff)
downloadcaxlsx-ca7248353d295c74f3dff7e8e003044849c026e7.tar.gz
caxlsx-ca7248353d295c74f3dff7e8e003044849c026e7.zip
epoc => epoch
Diffstat (limited to 'lib')
-rw-r--r--lib/axlsx/workbook/worksheet/date_time_converter.rb14
1 files changed, 7 insertions, 7 deletions
diff --git a/lib/axlsx/workbook/worksheet/date_time_converter.rb b/lib/axlsx/workbook/worksheet/date_time_converter.rb
index 5a572781..d2d9a014 100644
--- a/lib/axlsx/workbook/worksheet/date_time_converter.rb
+++ b/lib/axlsx/workbook/worksheet/date_time_converter.rb
@@ -9,8 +9,8 @@ module Axlsx
# @param [Date] date the date to be serialized
# @return [Numeric]
def self.date_to_serial(date)
- epoc = Axlsx::Workbook::date1904 ? Date.new(1904) : Date.new(1899, 12, 30)
- (date-epoc).to_f
+ epoch = Axlsx::Workbook::date1904 ? Date.new(1904) : Date.new(1899, 12, 30)
+ (date-epoch).to_f
end
# The time_to_serial methond converts a Time object its excel serialized form.
@@ -18,12 +18,12 @@ module Axlsx
# @return [Numeric]
def self.time_to_serial(time)
# Using hardcoded offsets here as some operating systems will not except
- # a 'negative' offset from the ruby epoc.
- epoc1900 = -2209161600 # Time.utc(1899, 12, 30).to_i
- epoc1904 = -2082844800 # Time.utc(1904, 1, 1).to_i
+ # a 'negative' offset from the ruby epoch.
+ epoch1900 = -2209161600 # Time.utc(1899, 12, 30).to_i
+ epoch1904 = -2082844800 # Time.utc(1904, 1, 1).to_i
seconds_per_day = 86400 # 60*60*24
- epoc = Axlsx::Workbook::date1904 ? epoc1904 : epoc1900
- (time.to_f - epoc)/seconds_per_day
+ epoch = Axlsx::Workbook::date1904 ? epoch1904 : epoch1900
+ (time.to_f - epoch)/seconds_per_day
end
end
end